## Typing stubs for zstd

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`zstd`](https://github.com/sergey-dryabzhinsky/python-zstd) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `zstd`. This version of
`types-zstd` aims to provide accurate annotations for
`zstd~=1.5.7.1`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/zstd`](https://github.com/python/typeshed/tree/main/stubs/zstd)
directory.

This package was tested with
mypy 1.16.1,
pyright 1.1.400,
and pytype 2024.10.11.
It was generated from typeshed commit
[`f4bf1d90a64d3f885ea30c642fe5373e2d19c344`](https://github.com/python/typeshed/commit/f4bf1d90a64d3f885ea30c642fe5373e2d19c344).